@@ -7,8 +7,8 @@ pub struct Margin {
 }
 
 impl Margin {
-    pub const fn new(horizontal: u16, vertical: u16) -> Margin {
-        Margin {
+    pub const fn new(horizontal: u16, vertical: u16) -> Self {
+        Self {
             horizontal,
             vertical,
         }
