@@ -17,13 +17,13 @@ pub use iter::*;
 #[derive(Debug, Default, Clone, Copy, Eq, PartialEq, Hash)]
 #[cfg_attr(feature = "serde", derive(serde::Serialize, serde::Deserialize))]
 pub struct Rect {
-    /// The x coordinate of the top left corner of the rect.
+    /// The x coordinate of the top left corner of the `Rect`.
     pub x: u16,
-    /// The y coordinate of the top left corner of the rect.
+    /// The y coordinate of the top left corner of the `Rect`.
     pub y: u16,
-    /// The width of the rect.
+    /// The width of the `Rect`.
     pub width: u16,
-    /// The height of the rect.
+    /// The height of the `Rect`.
     pub height: u16,
 }
 
@@ -47,9 +47,9 @@ impl fmt::Display for Rect {
 }
 
 impl Rect {
-    /// Creates a new rect, with width and height limited to keep the area under max u16. If
+    /// Creates a new `Rect`, with width and height limited to keep the area under max `u16`. If
     /// clipped, aspect ratio will be preserved.
-    pub fn new(x: u16, y: u16, width: u16, height: u16) -> Rect {
+    pub fn new(x: u16, y: u16, width: u16, height: u16) -> Self {
         let max_area = u16::max_value();
         let (clipped_width, clipped_height) =
             if u32::from(width) * u32::from(height) > u32::from(max_area) {
@@ -61,7 +61,7 @@ impl Rect {
             } else {
                 (width, height)
             };
-        Rect {
+        Self {
             x,
             y,
             width: clipped_width,
@@ -69,54 +69,57 @@ impl Rect {
         }
     }
 
-    /// The area of the rect. If the area is larger than the maximum value of u16, it will be
-    /// clamped to u16::MAX.
+    /// The area of the `Rect`. If the area is larger than the maximum value of `u16`, it will be
+    /// clamped to `u16::MAX`.
     pub const fn area(self) -> u16 {
         self.width.saturating_mul(self.height)
     }
 
-    /// Returns true if the rect has no area.
+    /// Returns true if the `Rect` has no area.
     pub const fn is_empty(self) -> bool {
         self.width == 0 || self.height == 0
     }
 
-    /// Returns the left coordinate of the rect.
+    /// Returns the left coordinate of the `Rect`.
     pub const fn left(self) -> u16 {
         self.x
     }
 
-    /// Returns the right coordinate of the rect. This is the first coordinate outside of the rect.
+    /// Returns the right coordinate of the `Rect`. This is the first coordinate outside of the
+    /// `Rect`.
     ///
     /// If the right coordinate is larger than the maximum value of u16, it will be clamped to
-    /// u16::MAX.
+    /// `u16::MAX`.
     pub const fn right(self) -> u16 {
         self.x.saturating_add(self.width)
     }
 
-    /// Returns the top coordinate of the rect.
+    /// Returns the top coordinate of the `Rect`.
     pub const fn top(self) -> u16 {
         self.y
     }
 
-    /// Returns the bottom coordinate of the rect. This is the first coordinate outside of the rect.
+    /// Returns the bottom coordinate of the `Rect`. This is the first coordinate outside of the
+    /// `Rect`.
     ///
     /// If the bottom coordinate is larger than the maximum value of u16, it will be clamped to
-    /// u16::MAX.
+    /// `u16::MAX`.
     pub const fn bottom(self) -> u16 {
         self.y.saturating_add(self.height)
     }
 
-    /// Returns a new rect inside the current one, with the given margin on each side.
+    /// Returns a new `Rect` inside the current one, with the given margin on each side.
     ///
-    /// If the margin is larger than the rect, the returned rect will have no area.
-    pub fn inner(self, margin: &Margin) -> Rect {
+    /// If the margin is larger than the `Rect`, the returned `Rect` will have no area.
+    #[must_use = "method returns the modified value"]
+    pub fn inner(self, margin: &Margin) -> Self {
         let doubled_margin_horizontal = margin.horizontal.saturating_mul(2);
         let doubled_margin_vertical = margin.vertical.saturating_mul(2);
 
         if self.width < doubled_margin_horizontal || self.height < doubled_margin_vertical {
-            Rect::default()
+            Self::default()
         } else {
-            Rect {
+            Self {
                 x: self.x.saturating_add(margin.horizontal),
                 y: self.y.saturating_add(margin.vertical),
                 width: self.width.saturating_sub(doubled_margin_horizontal),
@@ -133,25 +136,27 @@ impl Rect {
     /// - Positive `y` moves the whole `Rect` to the bottom, negative to the top.
     ///
     /// See [`Offset`] for details.
-    pub fn offset(self, offset: Offset) -> Rect {
-        Rect {
+    #[must_use = "method returns the modified value"]
+    pub fn offset(self, offset: Offset) -> Self {
+        Self {
             x: i32::from(self.x)
                 .saturating_add(offset.x)
-                .clamp(0, (u16::MAX - self.width) as i32) as u16,
+                .clamp(0, i32::from(u16::MAX - self.width)) as u16,
             y: i32::from(self.y)
                 .saturating_add(offset.y)
-                .clamp(0, (u16::MAX - self.height) as i32) as u16,
+                .clamp(0, i32::from(u16::MAX - self.height)) as u16,
             ..self
         }
     }
 
-    /// Returns a new rect that contains both the current one and the given one.
-    pub fn union(self, other: Rect) -> Rect {
+    /// Returns a new `Rect` that contains both the current one and the given one.
+    #[must_use = "method returns the modified value"]
+    pub fn union(self, other: Self) -> Self {
         let x1 = min(self.x, other.x);
         let y1 = min(self.y, other.y);
         let x2 = max(self.right(), other.right());
         let y2 = max(self.bottom(), other.bottom());
-        Rect {
+        Self {
             x: x1,
             y: y1,
             width: x2.saturating_sub(x1),
@@ -159,15 +164,16 @@ impl Rect {
         }
     }
 
-    /// Returns a new rect that is the intersection of the current one and the given one.
+    /// Returns a new `Rect` that is the intersection of the current one and the given one.
     ///
-    /// If the two rects do not intersect, the returned rect will have no area.
-    pub fn intersection(self, other: Rect) -> Rect {
+    /// If the two `Rect`s do not intersect, the returned `Rect` will have no area.
+    #[must_use = "method returns the modified value"]
+    pub fn intersection(self, other: Self) -> Self {
         let x1 = max(self.x, other.x);
         let y1 = max(self.y, other.y);
         let x2 = min(self.right(), other.right());
         let y2 = min(self.bottom(), other.bottom());
-        Rect {
+        Self {
             x: x1,
             y: y1,
             width: x2.saturating_sub(x1),
@@ -175,17 +181,17 @@ impl Rect {
         }
     }
 
-    /// Returns true if the two rects intersect.
-    pub const fn intersects(self, other: Rect) -> bool {
+    /// Returns true if the two `Rect`s intersect.
+    pub const fn intersects(self, other: Self) -> bool {
         self.x < other.right()
             && self.right() > other.x
             && self.y < other.bottom()
             && self.bottom() > other.y
     }
 
-    /// Returns true if the given position is inside the rect.
+    /// Returns true if the given position is inside the `Rect`.
     ///
-    /// The position is considered inside the rect if it is on the rect's border.
+    /// The position is considered inside the `Rect` if it is on the `Rect`'s border.
     ///
     /// # Examples
     ///
@@ -201,20 +207,20 @@ impl Rect {
             && position.y < self.bottom()
     }
 
-    /// Clamp this rect to fit inside the other rect.
+    /// Clamp this `Rect` to fit inside the other `Rect`.
     ///
-    /// If the width or height of this rect is larger than the other rect, it will be clamped to the
-    /// other rect's width or height.
+    /// If the width or height of this `Rect` is larger than the other `Rect`, it will be clamped to
+    /// the other `Rect`'s width or height.
     ///
-    /// If the left or top coordinate of this rect is smaller than the other rect, it will be
-    /// clamped to the other rect's left or top coordinate.
+    /// If the left or top coordinate of this `Rect` is smaller than the other `Rect`, it will be
+    /// clamped to the other `Rect`'s left or top coordinate.
     ///
-    /// If the right or bottom coordinate of this rect is larger than the other rect, it will be
-    /// clamped to the other rect's right or bottom coordinate.
+    /// If the right or bottom coordinate of this `Rect` is larger than the other `Rect`, it will be
+    /// clamped to the other `Rect`'s right or bottom coordinate.
     ///
-    /// This is different from [`Rect::intersection`] because it will move this rect to fit inside
-    /// the other rect, while [`Rect::intersection`] instead would keep this rect's position and
-    /// truncate its size to only that which is inside the other rect.
+    /// This is different from [`Rect::intersection`] because it will move this `Rect` to fit inside
+    /// the other `Rect`, while [`Rect::intersection`] instead would keep this `Rect`'s position and
+    /// truncate its size to only that which is inside the other `Rect`.
     ///
     /// # Examples
     ///
@@ -225,12 +231,13 @@ impl Rect {
     /// let rect = Rect::new(0, 0, 100, 100).clamp(area);
     /// # }
     /// ```
-    pub fn clamp(self, other: Rect) -> Rect {
+    #[must_use = "method returns the modified value"]
+    pub fn clamp(self, other: Self) -> Self {
         let width = self.width.min(other.width);
         let height = self.height.min(other.height);
         let x = self.x.clamp(other.x, other.right().saturating_sub(width));
         let y = self.y.clamp(other.y, other.bottom().saturating_sub(height));
-        Rect::new(x, y, width, height)
+        Self::new(x, y, width, height)
     }
 
     /// An iterator over rows within the `Rect`.
@@ -245,7 +252,7 @@ impl Rect {
     ///     }
     /// }
     /// ```
-    pub fn rows(self) -> Rows {
+    pub const fn rows(self) -> Rows {
         Rows::new(self)
     }
 
@@ -261,7 +268,7 @@ impl Rect {
     ///     }
     /// }
     /// ```
-    pub fn columns(self) -> Columns {
+    pub const fn columns(self) -> Columns {
         Columns::new(self)
     }
 
@@ -279,11 +286,11 @@ impl Rect {
     ///     }
     /// }
     /// ```
-    pub fn positions(self) -> Positions {
+    pub const fn positions(self) -> Positions {
         Positions::new(self)
     }
 
-    /// Returns a [`Position`] with the same coordinates as this rect.
+    /// Returns a [`Position`] with the same coordinates as this `Rect`.
     ///
     /// # Examples
     ///
@@ -292,15 +299,15 @@ impl Rect {
     /// let rect = Rect::new(1, 2, 3, 4);
     /// let position = rect.as_position();
     /// ````
-    pub fn as_position(self) -> Position {
+    pub const fn as_position(self) -> Position {
         Position {
             x: self.x,
             y: self.y,
         }
     }
 
-    /// Converts the rect into a size struct.
-    pub fn as_size(self) -> Size {
+    /// Converts the `Rect` into a size struct.
+    pub const fn as_size(self) -> Size {
         Size {
             width: self.width,
             height: self.height,
@@ -310,7 +317,7 @@ impl Rect {
 
 impl From<(Position, Size)> for Rect {
     fn from((position, size): (Position, Size)) -> Self {
-        Rect {
+        Self {
             x: position.x,
             y: position.y,
             width: size.width,
