@@ -3,11 +3,9 @@ use std::cmp::max;
 use strum::{Display, EnumString};
 use unicode_width::UnicodeWidthStr;
 
-use super::block::BlockExt;
 use crate::{
     layout::Flex,
     prelude::*,
-    symbols,
     widgets::{
         canvas::{Canvas, Line as CanvasLine, Points},
         Block, Borders,
@@ -56,7 +54,7 @@ impl<'a> Axis<'a> {
     ///
     /// This is a fluent setter method which must be chained or used as it consumes self
     #[must_use = "method moves the value of self and returns the modified value"]
-    pub fn title<T>(mut self, title: T) -> Axis<'a>
+    pub fn title<T>(mut self, title: T) -> Self
     where
         T: Into<Line<'a>>,
     {
@@ -70,7 +68,7 @@ impl<'a> Axis<'a> {
     ///
     /// This is a fluent setter method which must be chained or used as it consumes self
     #[must_use = "method moves the value of self and returns the modified value"]
-    pub fn bounds(mut self, bounds: [f64; 2]) -> Axis<'a> {
+    pub const fn bounds(mut self, bounds: [f64; 2]) -> Self {
         self.bounds = bounds;
         self
     }
@@ -98,7 +96,7 @@ impl<'a> Axis<'a> {
     ///         .labels(vec!["0".bold(), "25".into(), "50".bold()]);
     /// ```
     #[must_use = "method moves the value of self and returns the modified value"]
-    pub fn labels(mut self, labels: Vec<Span<'a>>) -> Axis<'a> {
+    pub fn labels(mut self, labels: Vec<Span<'a>>) -> Self {
         self.labels = Some(labels);
         self
     }
@@ -120,7 +118,7 @@ impl<'a> Axis<'a> {
     /// let axis = Axis::default().red();
     /// ```
     #[must_use = "method moves the value of self and returns the modified value"]
-    pub fn style<S: Into<Style>>(mut self, style: S) -> Axis<'a> {
+    pub fn style<S: Into<Style>>(mut self, style: S) -> Self {
         self.style = style.into();
         self
     }
@@ -133,7 +131,7 @@ impl<'a> Axis<'a> {
     ///
     /// On the X axis, this parameter only affects the first label.
     #[must_use = "method moves the value of self and returns the modified value"]
-    pub fn labels_alignment(mut self, alignment: Alignment) -> Axis<'a> {
+    pub const fn labels_alignment(mut self, alignment: Alignment) -> Self {
         self.labels_alignment = alignment;
         self
     }
@@ -178,14 +176,14 @@ pub enum LegendPosition {
 
 impl LegendPosition {
     fn layout(
-        &self,
+        self,
         area: Rect,
         legend_width: u16,
         legend_height: u16,
         x_title_width: u16,
         y_title_width: u16,
     ) -> Option<Rect> {
-        let mut height_margin = (area.height - legend_height) as i32;
+        let mut height_margin = i32::from(area.height - legend_height);
         if x_title_width != 0 {
             height_margin -= 1;
         }
@@ -322,7 +320,7 @@ impl<'a> Dataset<'a> {
     ///
     /// This is a fluent setter method which must be chained or used as it consumes self
     #[must_use = "method moves the value of self and returns the modified value"]
-    pub fn name<S>(mut self, name: S) -> Dataset<'a>
+    pub fn name<S>(mut self, name: S) -> Self
     where
         S: Into<Line<'a>>,
     {
@@ -332,7 +330,7 @@ impl<'a> Dataset<'a> {
 
     /// Sets the data points of this dataset
     ///
-    /// Points will then either be rendered as scrattered points or with lines between them
+    /// Points will then either be rendered as scattered points or with lines between them
     /// depending on [`Dataset::graph_type`].
     ///
     /// Data consist in an array of `f64` tuples (`(f64, f64)`), the first element being X and the
@@ -341,7 +339,7 @@ impl<'a> Dataset<'a> {
     ///
     /// This is a fluent setter method which must be chained or used as it consumes self
     #[must_use = "method moves the value of self and returns the modified value"]
-    pub fn data(mut self, data: &'a [(f64, f64)]) -> Dataset<'a> {
+    pub const fn data(mut self, data: &'a [(f64, f64)]) -> Self {
         self.data = data;
         self
     }
@@ -349,14 +347,14 @@ impl<'a> Dataset<'a> {
     /// Sets the kind of character to use to display this dataset
     ///
     /// You can use dots (`•`), blocks (`█`), bars (`▄`), braille (`⠓`, `⣇`, `⣿`) or half-blocks
-    /// (`█`, `▄`, and `▀`). See [symbols::Marker] for more details.
+    /// (`█`, `▄`, and `▀`). See [`symbols::Marker`] for more details.
     ///
     /// Note [`Marker::Braille`](symbols::Marker::Braille) requires a font that supports Unicode
     /// Braille Patterns.
     ///
     /// This is a fluent setter method which must be chained or used as it consumes self
     #[must_use = "method moves the value of self and returns the modified value"]
-    pub fn marker(mut self, marker: symbols::Marker) -> Dataset<'a> {
+    pub const fn marker(mut self, marker: symbols::Marker) -> Self {
         self.marker = marker;
         self
     }
@@ -369,7 +367,7 @@ impl<'a> Dataset<'a> {
     ///
     /// This is a fluent setter method which must be chained or used as it consumes self
     #[must_use = "method moves the value of self and returns the modified value"]
-    pub fn graph_type(mut self, graph_type: GraphType) -> Dataset<'a> {
+    pub const fn graph_type(mut self, graph_type: GraphType) -> Self {
         self.graph_type = graph_type;
         self
     }
@@ -394,7 +392,7 @@ impl<'a> Dataset<'a> {
     /// let dataset = Dataset::default().red();
     /// ```
     #[must_use = "method moves the value of self and returns the modified value"]
-    pub fn style<S: Into<Style>>(mut self, style: S) -> Dataset<'a> {
+    pub fn style<S: Into<Style>>(mut self, style: S) -> Self {
         self.style = style.into();
         self
     }
@@ -402,7 +400,6 @@ impl<'a> Dataset<'a> {
 
 /// A container that holds all the infos about where to display each elements of the chart (axis,
 /// labels, legend, ...).
-#[derive(Debug, Default, Clone, Eq, PartialEq, Hash)]
 struct ChartLayout {
     /// Location of the title of the x axis
     title_x: Option<(u16, u16)>,
@@ -496,7 +493,7 @@ pub struct Chart<'a> {
     style: Style,
     /// Constraints used to determine whether the legend should be shown or not
     hidden_legend_constraints: (Constraint, Constraint),
-    /// The position detnermine where the legenth is shown or hide regaurdless of
+    /// The position determine where the length is shown or hide regardless of
     /// `hidden_legend_constraints`
     legend_position: Option<LegendPosition>,
 }
@@ -527,8 +524,8 @@ impl<'a> Chart<'a> {
     ///     Dataset::default().data(&data_points2),
     /// ]);
     /// ```
-    pub fn new(datasets: Vec<Dataset<'a>>) -> Chart<'a> {
-        Chart {
+    pub fn new(datasets: Vec<Dataset<'a>>) -> Self {
+        Self {
             block: None,
             x_axis: Axis::default(),
             y_axis: Axis::default(),
@@ -543,7 +540,7 @@ impl<'a> Chart<'a> {
     ///
     /// This is a fluent setter method which must be chained or used as it consumes self
     #[must_use = "method moves the value of self and returns the modified value"]
-    pub fn block(mut self, block: Block<'a>) -> Chart<'a> {
+    pub fn block(mut self, block: Block<'a>) -> Self {
         self.block = Some(block);
         self
     }
@@ -557,7 +554,7 @@ impl<'a> Chart<'a> {
     ///
     /// This is a fluent setter method which must be chained or used as it consumes self
     #[must_use = "method moves the value of self and returns the modified value"]
-    pub fn style<S: Into<Style>>(mut self, style: S) -> Chart<'a> {
+    pub fn style<S: Into<Style>>(mut self, style: S) -> Self {
         self.style = style.into();
         self
     }
@@ -580,7 +577,7 @@ impl<'a> Chart<'a> {
     /// );
     /// ```
     #[must_use = "method moves the value of self and returns the modified value"]
-    pub fn x_axis(mut self, axis: Axis<'a>) -> Chart<'a> {
+    pub fn x_axis(mut self, axis: Axis<'a>) -> Self {
         self.x_axis = axis;
         self
     }
@@ -603,7 +600,7 @@ impl<'a> Chart<'a> {
     /// );
     /// ```
     #[must_use = "method moves the value of self and returns the modified value"]
-    pub fn y_axis(mut self, axis: Axis<'a>) -> Chart<'a> {
+    pub fn y_axis(mut self, axis: Axis<'a>) -> Self {
         self.y_axis = axis;
         self
     }
@@ -639,7 +636,7 @@ impl<'a> Chart<'a> {
     /// let chart = Chart::new(vec![]).hidden_legend_constraints(constraints);
     /// ```
     ///
-    /// Always hide the legend. Note this can be accomplished more exclicitely by passing `None` to
+    /// Always hide the legend. Note this can be accomplished more explicitly by passing `None` to
     /// [`Chart::legend_position`].
     ///
     /// ```
@@ -648,7 +645,10 @@ impl<'a> Chart<'a> {
     /// let chart = Chart::new(vec![]).hidden_legend_constraints(constraints);
     /// ```
     #[must_use = "method moves the value of self and returns the modified value"]
-    pub fn hidden_legend_constraints(mut self, constraints: (Constraint, Constraint)) -> Chart<'a> {
+    pub const fn hidden_legend_constraints(
+        mut self,
+        constraints: (Constraint, Constraint),
+    ) -> Self {
         self.hidden_legend_constraints = constraints;
         self
     }
@@ -683,57 +683,70 @@ impl<'a> Chart<'a> {
     /// let chart = Chart::new(vec![]).legend_position(None);
     /// ```
     #[must_use = "method moves the value of self and returns the modified value"]
-    pub fn legend_position(mut self, position: Option<LegendPosition>) -> Chart<'a> {
+    pub const fn legend_position(mut self, position: Option<LegendPosition>) -> Self {
         self.legend_position = position;
         self
     }
 
     /// Compute the internal layout of the chart given the area. If the area is too small some
     /// elements may be automatically hidden
-    fn layout(&self, area: Rect) -> ChartLayout {
-        let mut layout = ChartLayout::default();
+    fn layout(&self, area: Rect) -> Option<ChartLayout> {
         if area.height == 0 || area.width == 0 {
-            return layout;
+            return None;
         }
         let mut x = area.left();
         let mut y = area.bottom() - 1;
 
+        let mut label_x = None;
         if self.x_axis.labels.is_some() && y > area.top() {
-            layout.label_x = Some(y);
+            label_x = Some(y);
             y -= 1;
         }
 
-        layout.label_y = self.y_axis.labels.as_ref().and(Some(x));
+        let label_y = self.y_axis.labels.as_ref().and(Some(x));
         x += self.max_width_of_labels_left_of_y_axis(area, self.y_axis.labels.is_some());
 
+        let mut axis_x = None;
         if self.x_axis.labels.is_some() && y > area.top() {
-            layout.axis_x = Some(y);
+            axis_x = Some(y);
             y -= 1;
         }
 
+        let mut axis_y = None;
         if self.y_axis.labels.is_some() && x + 1 < area.right() {
-            layout.axis_y = Some(x);
+            axis_y = Some(x);
             x += 1;
         }
 
-        if x < area.right() && y > 1 {
-            layout.graph_area = Rect::new(x, area.top(), area.right() - x, y - area.top() + 1);
-        }
+        let graph_width = area.right().saturating_sub(x);
+        let graph_height = y.saturating_sub(area.top()).saturating_add(1);
+        debug_assert_ne!(
+            graph_width, 0,
+            "Axis and labels should have been hidden due to the small area"
+        );
+        debug_assert_ne!(
+            graph_height, 0,
+            "Axis and labels should have been hidden due to the small area"
+        );
+        let graph_area = Rect::new(x, area.top(), graph_width, graph_height);
 
+        let mut title_x = None;
         if let Some(ref title) = self.x_axis.title {
             let w = title.width() as u16;
-            if w < layout.graph_area.width && layout.graph_area.height > 2 {
-                layout.title_x = Some((x + layout.graph_area.width - w, y));
+            if w < graph_area.width && graph_area.height > 2 {
+                title_x = Some((x + graph_area.width - w, y));
             }
         }
 
+        let mut title_y = None;
         if let Some(ref title) = self.y_axis.title {
             let w = title.width() as u16;
-            if w + 1 < layout.graph_area.width && layout.graph_area.height > 2 {
-                layout.title_y = Some((x, area.top()));
+            if w + 1 < graph_area.width && graph_area.height > 2 {
+                title_y = Some((x, area.top()));
             }
         }
 
+        let mut legend_area = None;
         if let Some(legend_position) = self.legend_position {
             let legends = self
                 .datasets
@@ -746,27 +759,25 @@ impl<'a> Chart<'a> {
 
                 let [max_legend_width] = Layout::horizontal([self.hidden_legend_constraints.0])
                     .flex(Flex::Start)
-                    .areas(layout.graph_area);
+                    .areas(graph_area);
 
                 let [max_legend_height] = Layout::vertical([self.hidden_legend_constraints.1])
                     .flex(Flex::Start)
-                    .areas(layout.graph_area);
+                    .areas(graph_area);
 
                 if inner_width > 0
                     && legend_width <= max_legend_width.width
                     && legend_height <= max_legend_height.height
                 {
-                    layout.legend_area = legend_position.layout(
-                        layout.graph_area,
+                    legend_area = legend_position.layout(
+                        graph_area,
                         legend_width,
                         legend_height,
-                        layout
-                            .title_x
+                        title_x
                             .and(self.x_axis.title.as_ref())
                             .map(|t| t.width() as u16)
                             .unwrap_or_default(),
-                        layout
-                            .title_y
+                        title_y
                             .and(self.y_axis.title.as_ref())
                             .map(|t| t.width() as u16)
                             .unwrap_or_default(),
@@ -774,7 +785,16 @@ impl<'a> Chart<'a> {
                 }
             }
         }
-        layout
+        Some(ChartLayout {
+            title_x,
+            title_y,
+            label_x,
+            label_y,
+            axis_x,
+            axis_y,
+            legend_area,
+            graph_area,
+        })
     }
 
     fn max_width_of_labels_left_of_y_axis(&self, area: Rect, has_y_axis: bool) -> u16 {
@@ -923,26 +943,22 @@ impl Widget for Chart<'_> {
 }
 
 impl WidgetRef for Chart<'_> {
+    #[allow(clippy::too_many_lines)]
     fn render_ref(&self, area: Rect, buf: &mut Buffer) {
         buf.set_style(area, self.style);
 
         self.block.render_ref(area, buf);
         let chart_area = self.block.inner_if_some(area);
-        if chart_area.is_empty() {
+        let Some(layout) = self.layout(chart_area) else {
             return;
-        }
+        };
+        let graph_area = layout.graph_area;
 
         // Sample the style of the entire widget. This sample will be used to reset the style of
         // the cells that are part of the components put on top of the grah area (i.e legend and
         // axis names).
         let original_style = buf.get(area.left(), area.top()).style();
 
-        let layout = self.layout(chart_area);
-        let graph_area = layout.graph_area;
-        if graph_area.width < 1 || graph_area.height < 1 {
-            return;
-        }
-
         self.render_x_labels(buf, &layout, chart_area, graph_area);
         self.render_y_labels(buf, &layout, chart_area, graph_area);
 
@@ -981,7 +997,7 @@ impl WidgetRef for Chart<'_> {
                         coords: dataset.data,
                         color: dataset.style.fg.unwrap_or(Color::Reset),
                     });
-                    if let GraphType::Line = dataset.graph_type {
+                    if dataset.graph_type == GraphType::Line {
                         for data in dataset.data.windows(2) {
                             ctx.draw(&CanvasLine {
                                 x1: data[0].0,
@@ -1060,7 +1076,7 @@ impl WidgetRef for Chart<'_> {
 }
 
 impl<'a> Styled for Axis<'a> {
-    type Item = Axis<'a>;
+    type Item = Self;
 
     fn style(&self) -> Style {
         self.style
@@ -1072,7 +1088,7 @@ impl<'a> Styled for Axis<'a> {
 }
 
 impl<'a> Styled for Dataset<'a> {
-    type Item = Dataset<'a>;
+    type Item = Self;
 
     fn style(&self) -> Style {
         self.style
@@ -1084,7 +1100,7 @@ impl<'a> Styled for Dataset<'a> {
 }
 
 impl<'a> Styled for Chart<'a> {
-    type Item = Chart<'a>;
+    type Item = Self;
 
     fn style(&self) -> Style {
         self.style
@@ -1100,10 +1116,7 @@ mod tests {
     use strum::ParseError;
 
     use super::*;
-    use crate::{
-        assert_buffer_eq,
-        style::{Modifier, Stylize},
-    };
+    use crate::assert_buffer_eq;
 
     struct LegendTestCase {
         chart_area: Rect,
@@ -1137,7 +1150,7 @@ mod tests {
                 .x_axis(Axis::default().title("X axis"))
                 .y_axis(Axis::default().title("Y axis"))
                 .hidden_legend_constraints(case.hidden_legend_constraints);
-            let layout = chart.layout(case.chart_area);
+            let layout = chart.layout(case.chart_area).unwrap();
             assert_eq!(layout.legend_area, case.legend_area);
         }
     }
@@ -1151,7 +1164,7 @@ mod tests {
                 .bg(Color::White)
                 .add_modifier(Modifier::BOLD)
                 .remove_modifier(Modifier::DIM)
-        )
+        );
     }
 
     #[test]
@@ -1163,7 +1176,7 @@ mod tests {
                 .bg(Color::White)
                 .add_modifier(Modifier::BOLD)
                 .remove_modifier(Modifier::DIM)
-        )
+        );
     }
 
     #[test]
@@ -1175,7 +1188,7 @@ mod tests {
                 .bg(Color::White)
                 .add_modifier(Modifier::BOLD)
                 .remove_modifier(Modifier::DIM)
-        )
+        );
     }
 
     #[test]
@@ -1199,7 +1212,7 @@ mod tests {
         let mut buffer = Buffer::empty(Rect::new(0, 0, 8, 4));
         widget.render(buffer.area, &mut buffer);
 
-        assert_eq!(buffer, Buffer::with_lines(vec![" ".repeat(8); 4]))
+        assert_eq!(buffer, Buffer::with_lines(vec![" ".repeat(8); 4]));
     }
 
     #[test]
@@ -1209,7 +1222,7 @@ mod tests {
         let data_unnamed = Dataset::default(); // must not occupy a row in legend
         let widget = Chart::new(vec![data_named_1, data_unnamed, data_named_2]);
         let buffer = Buffer::empty(Rect::new(0, 0, 50, 25));
-        let layout = widget.layout(buffer.area);
+        let layout = widget.layout(buffer.area).unwrap();
 
         assert!(layout.legend_area.is_some());
         assert_eq!(layout.legend_area.unwrap().height, 4); // 2 for borders, 2 for rows
@@ -1220,7 +1233,7 @@ mod tests {
         let dataset = Dataset::default();
         let widget = Chart::new(vec![dataset; 3]);
         let buffer = Buffer::empty(Rect::new(0, 0, 50, 25));
-        let layout = widget.layout(buffer.area);
+        let layout = widget.layout(buffer.area).unwrap();
 
         assert!(layout.legend_area.is_none());
     }
@@ -1355,7 +1368,7 @@ mod tests {
 
         let expected = Buffer::with_lines(vec!["┌────┐", "│Data│", "└────┘"]);
 
-        [
+        for position in [
             LegendPosition::TopLeft,
             LegendPosition::Top,
             LegendPosition::TopRight,
@@ -1364,16 +1377,15 @@ mod tests {
             LegendPosition::Bottom,
             LegendPosition::BottomLeft,
             LegendPosition::BottomRight,
-        ]
-        .iter()
-        .for_each(|&position| {
+        ] {
             let chart = chart.clone().legend_position(Some(position));
             buffer.reset();
             chart.render(buffer.area, &mut buffer);
             assert_eq!(buffer, expected);
-        });
+        }
     }
 
+    #[allow(clippy::too_many_lines)]
     #[test]
     fn test_legend_of_chart_have_odd_margin_size() {
         let name = "Data";
