@@ -1,13 +1,12 @@
 use unicode_width::UnicodeWidthStr;
 
-use super::block::BlockExt;
 use crate::{
     prelude::*,
     text::StyledGrapheme,
     widgets::{reflow::*, Block},
 };
 
-fn get_line_offset(line_width: u16, text_area_width: u16, alignment: Alignment) -> u16 {
+const fn get_line_offset(line_width: u16, text_area_width: u16, alignment: Alignment) -> u16 {
     match alignment {
         Alignment::Center => (text_area_width / 2).saturating_sub(line_width / 2),
         Alignment::Right => text_area_width.saturating_sub(line_width),
@@ -107,11 +106,11 @@ impl<'a> Paragraph<'a> {
     /// let paragraph = Paragraph::new(Text::styled("Hello, world!", Style::default()));
     /// let paragraph = Paragraph::new(Line::from(vec!["Hello, ".into(), "world!".red()]));
     /// ```
-    pub fn new<T>(text: T) -> Paragraph<'a>
+    pub fn new<T>(text: T) -> Self
     where
         T: Into<Text<'a>>,
     {
-        Paragraph {
+        Self {
             block: None,
             style: Style::default(),
             wrap: None,
@@ -131,7 +130,7 @@ impl<'a> Paragraph<'a> {
     ///     .block(Block::default().title("Paragraph").borders(Borders::ALL));
     /// ```
     #[must_use = "method moves the value of self and returns the modified value"]
-    pub fn block(mut self, block: Block<'a>) -> Paragraph<'a> {
+    pub fn block(mut self, block: Block<'a>) -> Self {
         self.block = Some(block);
         self
     }
@@ -151,7 +150,7 @@ impl<'a> Paragraph<'a> {
     /// let paragraph = Paragraph::new("Hello, world!").style(Style::new().red().on_white());
     /// ```
     #[must_use = "method moves the value of self and returns the modified value"]
-    pub fn style<S: Into<Style>>(mut self, style: S) -> Paragraph<'a> {
+    pub fn style<S: Into<Style>>(mut self, style: S) -> Self {
         self.style = style.into();
         self
     }
@@ -167,7 +166,7 @@ impl<'a> Paragraph<'a> {
     /// let paragraph = Paragraph::new("Hello, world!").wrap(Wrap { trim: true });
     /// ```
     #[must_use = "method moves the value of self and returns the modified value"]
-    pub fn wrap(mut self, wrap: Wrap) -> Paragraph<'a> {
+    pub const fn wrap(mut self, wrap: Wrap) -> Self {
         self.wrap = Some(wrap);
         self
     }
@@ -184,7 +183,7 @@ impl<'a> Paragraph<'a> {
     /// For more information about future scrolling design and concerns, see [RFC: Design of
     /// Scrollable Widgets](https://github.com/ratatui-org/ratatui/issues/174) on GitHub.
     #[must_use = "method moves the value of self and returns the modified value"]
-    pub fn scroll(mut self, offset: (Vertical, Horizontal)) -> Paragraph<'a> {
+    pub const fn scroll(mut self, offset: (Vertical, Horizontal)) -> Self {
         self.scroll = offset;
         self
     }
@@ -201,7 +200,7 @@ impl<'a> Paragraph<'a> {
     /// let paragraph = Paragraph::new("Hello World").alignment(Alignment::Center);
     /// ```
     #[must_use = "method moves the value of self and returns the modified value"]
-    pub fn alignment(mut self, alignment: Alignment) -> Paragraph<'a> {
+    pub const fn alignment(mut self, alignment: Alignment) -> Self {
         self.alignment = alignment;
         self
     }
@@ -217,7 +216,7 @@ impl<'a> Paragraph<'a> {
     /// let paragraph = Paragraph::new("Hello World").left_aligned();
     /// ```
     #[must_use = "method moves the value of self and returns the modified value"]
-    pub fn left_aligned(self) -> Self {
+    pub const fn left_aligned(self) -> Self {
         self.alignment(Alignment::Left)
     }
 
@@ -232,7 +231,7 @@ impl<'a> Paragraph<'a> {
     /// let paragraph = Paragraph::new("Hello World").centered();
     /// ```
     #[must_use = "method moves the value of self and returns the modified value"]
-    pub fn centered(self) -> Self {
+    pub const fn centered(self) -> Self {
         self.alignment(Alignment::Center)
     }
 
@@ -247,7 +246,7 @@ impl<'a> Paragraph<'a> {
     /// let paragraph = Paragraph::new("Hello World").right_aligned();
     /// ```
     #[must_use = "method moves the value of self and returns the modified value"]
-    pub fn right_aligned(self) -> Self {
+    pub const fn right_aligned(self) -> Self {
         self.alignment(Alignment::Right)
     }
 
@@ -257,6 +256,8 @@ impl<'a> Paragraph<'a> {
     /// need in order to be fully rendered. For paragraphs that do not use wrapping, this count is
     /// simply the number of lines present in the paragraph.
     ///
+    /// Note: The design for text wrapping is not stable and might affect this API.
+    ///
     /// # Example
     ///
     /// ```ignore
@@ -268,7 +269,6 @@ impl<'a> Paragraph<'a> {
     /// ```
     #[stability::unstable(
         feature = "rendered-line-info",
-        reason = "The design for text wrapping is not stable and might affect this API.",
         issue = "https://github.com/ratatui-org/ratatui/issues/293"
     )]
     pub fn line_count(&self, width: u16) -> usize {
@@ -298,6 +298,8 @@ impl<'a> Paragraph<'a> {
 
     /// Calculates the shortest line width needed to avoid any word being wrapped or truncated.
     ///
+    /// Note: The design for text wrapping is not stable and might affect this API.
+    ///
     /// # Example
     ///
     /// ```ignore
@@ -310,7 +312,6 @@ impl<'a> Paragraph<'a> {
     /// ```
     #[stability::unstable(
         feature = "rendered-line-info",
-        reason = "The design for text wrapping is not stable and might affect this API.",
         issue = "https://github.com/ratatui-org/ratatui/issues/293"
     )]
     pub fn line_width(&self) -> usize {
@@ -339,8 +340,9 @@ impl Paragraph<'_> {
             return;
         }
 
+        buf.set_style(text_area, self.style);
         let styled = self.text.iter().map(|line| {
-            let graphemes = line.styled_graphemes(self.style);
+            let graphemes = line.styled_graphemes(self.text.style);
             let alignment = line.alignment.unwrap_or(self.alignment);
             (graphemes, alignment)
         });
@@ -390,7 +392,7 @@ impl<'a> Paragraph<'a> {
 }
 
 impl<'a> Styled for Paragraph<'a> {
-    type Item = Paragraph<'a>;
+    type Item = Self;
 
     fn style(&self) -> Style {
         self.style
@@ -406,16 +408,14 @@ mod test {
     use super::*;
     use crate::{
         backend::TestBackend,
-        style::{Color, Modifier, Stylize},
-        text::{Line, Span},
         widgets::{block::Position, Borders},
-        Terminal,
     };
 
     /// Tests the [`Paragraph`] widget against the expected [`Buffer`] by rendering it onto an equal
     /// area and comparing the rendered and expected content.
     /// This can be used for easy testing of varying configured paragraphs with the same expected
     /// buffer or any other test case really.
+    #[allow(clippy::needless_pass_by_value)]
     fn test_case(paragraph: &Paragraph, expected: Buffer) {
         let backend = TestBackend::new(expected.area.width, expected.area.height);
         let mut terminal = Terminal::new(backend).unwrap();
@@ -952,7 +952,7 @@ mod test {
                 .bg(Color::White)
                 .add_modifier(Modifier::BOLD)
                 .remove_modifier(Modifier::DIM)
-        )
+        );
     }
 
     #[test]
@@ -1014,4 +1014,26 @@ mod test {
         let p = Paragraph::new("Hello, world!").right_aligned();
         assert_eq!(p.alignment, Alignment::Right);
     }
+
+    /// Regression test for <https://github.com/ratatui-org/ratatui/issues/990>
+    ///
+    /// This test ensures that paragraphs with a block and styled text are rendered correctly.
+    /// It has been simplified from the original issue but tests the same functionality.
+    #[test]
+    fn paragraph_block_text_style() {
+        let text = Text::styled("Styled text", Color::Green);
+        let paragraph = Paragraph::new(text).block(Block::bordered());
+
+        let mut buf = Buffer::empty(Rect::new(0, 0, 20, 3));
+        paragraph.render(Rect::new(0, 0, 20, 3), &mut buf);
+
+        let mut expected = Buffer::with_lines(vec![
+            "┌──────────────────┐",
+            "│Styled text       │",
+            "└──────────────────┘",
+        ]);
+        expected.set_style(Rect::new(1, 1, 11, 1), Style::default().fg(Color::Green));
+
+        assert_eq!(buf, expected);
+    }
 }
